%--------------------------------------------------------------------------
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%  Basketball Freiwurf, Abbildung 2.6:
%     Bestimmung der maximal moeglichen Abweichung des Abwurfwinkels
%     von einem Abwurfwinkel theta0 bei fester Abwurfgeschindigkeit v0
%     die so gewhlt ist, dass der Wurf mit theta0 durch das Zentrum des
%     Rings geht. Es wird nur Schwerkraft betrachtet, also Wurfparabeln
%     als Trajektorien.
%
%  Skript: Aufruf der Funktion
%  function [maxFehler, thetaMin, thetaMax] = fehlerWinkel(theta0,hS)
%     theta0:     Referenz-Abwurfwinkel (in Grad)
%     hS:         Groesse des Werfers
%     thetaMin:   minimaler Abwurfwinkel, so dass Ball noch im Korb
%     thetaMax:   maximaler Abwurfwinkel, so dass Ball noch im Korb
%     maxFehler:  min(thetaMax - theta0, theta0 - thetaMin)
%      
% Plot von maxFehler ueber theta0;
% Bestimmung des besten Abwurfwinkels theta0 mit fminsearch
%
%     Author: Frank Hausser
%     Date:   8/2009
%--------------------------------------------------------------------------

close all;
clear all;

theta0 = linspace(40,60,1000);

hS1 = 2.13;
hS2 = 2.00;
hS3 = 1.87;


thetaOpt1 = fminsearch(@(x) (-fehlerWinkel(x,hS1)),45)
thetaOpt2 = fminsearch(@(x) (-fehlerWinkel(x,hS2)),45)
thetaOpt3 = fminsearch(@(x) (-fehlerWinkel(x,hS3)),45)

for k=1:1000
   err1(k) = fehlerWinkel(theta0(k),hS1);
end

for k=1:1000
   err2(k) = fehlerWinkel(theta0(k),hS2);
end

for k=1:1000
   err3(k) = fehlerWinkel(theta0(k),hS3);
end

%---------------------- Plot ----------------------------------------------
set(0,'DefaultAxesLineStyleOrder',{'-',':','--'})
set(0,'DefaultAxesColorOrder',[0,0,0])
plot(theta0,err1,theta0,err2,theta0,err3,'linewidth',2);
text1 = '2.13 m, \theta^0_{opt} = 48.43^\circ';
text2 = '2.00 m, \theta^0_{opt} = 49.59^\circ';
text3 = '1.87 m, \theta^0_{opt} = 50.74^\circ';

legend(text1,text2,text3,'location','Best')
xlabel('\theta^0')
ylabel('e(\theta^0)')
