%--------------------------------------------------------------------------
%     Mathematische Modellierung mit MATLAB F. Hausser und Y. Luchko
%  
%     Basketball Freiwurf: Beste Wurfbahn, Abbildungen 2.8, 2.9
%             Bestimmung der erlaubten Fehler in Winkel und Geschwindigkeit
%     
%     Testskript fuer die Funktion 
%             [thetaMinMax, vMinMax] = fehlerWurfbahn(theta0,v0,hS)
%      
%     Author: Frank Hausser
%     Date:   8/2009
%--------------------------------------------------------------------------

clear all;
close all;

hS       = 2.13; % Groesse des Spielers [m]
nTheta   = 100;  % Anzahl Diskretisierungspunkte fuer Abwurfwinkel
nV       = 100;  % Anzahl Diskretisierungspunkte fuer Abwurfgeschwindigkeit
theta0   = linspace(35,60,nTheta);
v0       = linspace(6.6,7.0,nV);
w        = 5;  % Gewicht fr Geschwindigkeit

[v0_i,theta0_i] = meshgrid(v0,theta0);

fehlerTheta             = zeros(nTheta,nV);
fehlerV                 = zeros(nTheta,nV);
fehlerGewichtetProzent  = zeros(nTheta,nV);

for k=1:nTheta
    for l=1:nV
        [thetaMinMax,vMinMax] ...
            = fehlerWurfbahn(theta0_i(k,l),v0_i(k,l),hS);
        if isempty(thetaMinMax)
            fehlerTheta(k,l) = 0;
            fehlerV(k,l)     = 0;
        else    
            fehlerTheta(k,l) = min(theta0_i(k,l) - thetaMinMax(1), ...
                                   thetaMinMax(2) - theta0_i(k,l) );
            fehlerV(k,l)     = min(v0_i(k,l) - vMinMax(1), ...
                                   vMinMax(2) - v0_i(k,l) );
              
            fehlerGewichtetProzent(k,l) = ...
                100*min(  fehlerTheta(k,l)/theta0_i(k,l), ...
                          w* fehlerV(k,l)/v0_i(k,l) );                
        end
    end
end


%------------------------ plots -------------------------------------------
% Erlaubter Fehler in theta (absolut)
figure(1), contourf(v0_i,theta0_i,fehlerTheta,10);
xlabel('Abwurfgeschwindigkeit v^0 [m/s]');
ylabel('Abwurfwinkel \theta^0 [\circ]');
title('Erlaubter Fehler in \theta^0 [\circ]');
%colormap('gray');
colorbar;

% Erlaubter Fehler in v (absolut)
figure(2), contourf(v0_i,theta0_i,fehlerV,10);
xlabel('Abwurfgeschwindigkeit v^0 [m/s]');
ylabel('Abwurfwinkel \theta^0 [\circ]');
title('Erlaubter Fehler in v^0 [m/s]')
%colormap('gray');
colorbar

% Erlaubter Fehler in theta (Prozent)
fehlerThetaProzent = 100*fehlerTheta./theta0_i;
figure(3), contourf(v0_i,theta0_i,fehlerThetaProzent,10);
xlabel('Abwurfgeschwindigkeit v^0 [m/s]');
ylabel('Abwurfwinkel \theta^0 [\circ]');
title('Erlaubter Fehler in \theta^0 [Prozent]');
%colormap('gray');
colorbar;

% Erlaubter Fehler in v (Prozent)
fehlerVProzent = 100*fehlerV./v0_i;
figure(4), contourf(v0_i,theta0_i,fehlerVProzent,10);
xlabel('Abwurfgeschwindigkeit v^0 [m/s]');
ylabel('Abwurfwinkel \theta^0 [\circ]');
title('Erlaubter Fehler in v^0 [Prozent]')
%colormap('gray');
colorbar

% Erlaubter gewichteter Fehler: 
figure(5), contourf(v0_i,theta0_i,fehlerGewichtetProzent,10);
xlabel('Abwurfgeschwindigkeit v^0 [m/s]');
ylabel('Abwurfwinkel \theta^0 [\circ]');
title('Erlaubter gewichteter Fehler [Prozent]')
%colormap('gray');
colorbar


