%--------------------------------------------------------------------------
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko, 2010  %
%    Spiralgitter mit generierender Fermatscher Spirale                   % 
%--------------------------------------------------------------------------

close all;
clear all;

%------------- Spiralgitter -----------------------------------------------
div      = (3 - sqrt(5) )/2;   % Divergenz
deltaPhi = 2*pi*div;           % Winkel zwischen zwei aufeindanderfolgenden
                               % Gitterpunkten
n        = 20;                 % Anzahl Gitterpunkte
a        = n/sqrt(n*2*pi);     % Parameter fuer generierende Spirale

% Polardarstellung
phiDiskret  = [0:deltaPhi:(n-1)*deltaPhi];
rDiskret      = a*sqrt(phiDiskret);
%Umrechnung in kartesische Koordinaten
xDiskret = rDiskret.*cos(phiDiskret);
yDiskret = rDiskret.*sin(phiDiskret);

%------------------- Generierende Spirale ---------------------------------
phiKont    =  [0:deltaPhi/100:(n-1)*deltaPhi];
rKont      =  a*sqrt(phiKont);
xKont      = rKont.*cos(phiKont);
yKont      = rKont.*sin(phiKont);

%-------------- Plot der Spiralen -----------------------------------------
set(0,'DefaultAxesColorOrder',[0,0,0])
hold on
plot(xKont,yKont,'-');
h = plot(xDiskret,yDiskret,'o');
set(h,'MarkerSize',10,'MarkerFaceColor','w','LineWidth',2)
axis square
axis off

plot( xDiskret(1:2),yDiskret(1:2),'k','LineWidth',2);
plot( xDiskret(1:2:3),yDiskret(1:2:3),'k','LineWidth',2);
plot( xDiskret(1:3:4),yDiskret(1:3:4),'k','LineWidth',2);

hold off
