%--------------------------------------------------------------------------
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko, 2010  %
%                                                                         %                                                                  %
%    Simulation eines zellulaeren Automaten: Conway's Game of Life        %
%    angelehnt an lifex.m von C. Moler, Experiments with MATLAB,          %
%                                    http://www.mathworks.com/moler       %
%--------------------------------------------------------------------------

% Anfangspopulation 
iniPop = sparse([1 1 1 1 1 0 1 1 1 1 1;]);

% Zellraum und Anfangspopulation setzen
[p,q] = size(iniPop);
n     = max(p,q) + 10;
Pop   = sparse(n,n);
iCol  = floor((n-p)/2)+(1:p);
iRow  = floor((n-q)/2)+(1:q);
Pop(iCol,iRow) = iniPop;

%----------- Zeitschleife -------------------------------------------------
while 1   % Endlos
    %------------------ Plot ----------------------------------------------
    spy(Pop); pause(0.5);
    
    %---------- Berechnung des neuen Zustandes ----------------------------
    indL = [1 1:n-1]; % um eins nach links verschobener Index 
    indR = [2:n n];   % um eins nach rechts verschobener Index 
    
    % Berechnung, wieviele der 8 Nachbarn lebend sind (Zustand 1 haben)
    L = Pop(:,indL)    + Pop(:,indR)    + Pop(indL,:)  + Pop(indR,:) + ...
        Pop(indL,indL) + Pop(indR,indR) + Pop(indL,indR) + Pop(indR,indL);
    
    % Eine lebende Zelle mit 2 lebenden Nachbarn oder eine beliebige Zelle
    % mit 3 Nachbarn ist im nchsten Schritt am Leben
    Pop = ((Pop == 1) & (L == 2)) | (L == 3);
end
