%--------------------------------------------------------------------------   
%     Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%     Linearisierung des mathematischen Pendels, Abbildung 5.1 
%--------------------------------------------------------------------------

clear all;

% rechte Seiten der DGL 
g = @(t,phi) [-phi(2); phi(1)];          % linearisiert
f = @(t,phi) [-phi(2); sin( phi(1) )];   % nichtlinear 

%----------------  Plot der rechten Seite --------------------------------
phiTest = linspace(-pi,pi,500);
gPhi = phiTest;
fPhi = sin(phiTest);
figure(1)
plot(phiTest,fPhi,  'linewidth',2, 'Color', 'k');
hold on;
plot(phiTest,gPhi, '--', 'linewidth',2, 'Color', 'k');
hold off;
legend('f(\phi) = sin(\phi)', ' g(\phi) = \phi');
xlabel('Auslenkung \phi');
set(gca,'XTick',-pi:pi/2:pi)
set(gca,'XTickLabel',{'-pi','-pi/2','0','pi/2','pi'})
axis([-pi pi -3 3]);


%------------- Berechnung der Loesungen ---------------------------------
tIntervall = [0, 4*pi];      % Zeitintervall
phi0       = [pi/4, 0];      % Anfangswerte (kleine Auslenkung)
[tLin1,phiLin1]       = ode45(g, tIntervall, phi0); 
[tNonlin1,phiNonlin1] = ode45(f, tIntervall, phi0); 

phi0 = [3*pi/4, 0];          % Anfangswerte (grosse Auslenkung)
[tLin2,phiLin2]       = ode45(g, tIntervall, phi0); 
[tNonlin2,phiNonlin2] = ode45(f, tIntervall, phi0); 

%------------------  Plot der Loesungen ----------------------------------

% Winkel phi, kleine Amplitude
figure(2)
plot(tNonlin1,phiNonlin1(:,1),  'linewidth',2, 'Color', 'k');
hold on;
plot(tLin1, phiLin1(:,1), '--', 'linewidth',2, 'Color', 'k');
hold off;

legend('nichtlinear', 'linearisiert');
xlabel('Zeit t');
ylabel('Auslenkung \phi(t)')
axis([0 4*pi -1 1]);
set(gca,'YTick',-pi/4:pi/4:pi/4)
set(gca,'YTickLabel',{'-pi/4','0','pi/4'})

% Winkelgeschwindigkeit omega, kleine Amplitude
figure(3)
plot(tNonlin1,phiNonlin1(:,2),  'linewidth',2, 'Color', 'k');
hold on;
plot(tLin1, phiLin1(:,2), '--', 'linewidth',2, 'Color', 'k');
hold off;

legend('nichtlinear', 'linearisiert');
xlabel('Zeit t');
ylabel('Winkelgeschwindigkeit \omega(t)')
axis([0 4*pi -1 1]);
set(gca,'YTick',-pi/4:pi/4:pi/4)
set(gca,'YTickLabel',{'-pi/4','0','pi/4'})


% Winkel phi, grosse Amplitude
figure(4)
plot(tNonlin2,phiNonlin2(:,1),  'linewidth',2, 'Color', 'k');
hold on;
plot(tLin2, phiLin2(:,1), '--', 'linewidth',2, 'Color', 'k');
hold off;

legend('nichtlinear', 'linearisiert');
xlabel('Zeit t');
ylabel('Auslenkung \phi(t)')
axis([0 4*pi -3 3]);
set(gca,'YTick',-3*pi/4:pi/2:3*pi/4)
set(gca,'YTickLabel',{'-3pi/4','-pi/4','pi/4','3pi/4'})


% Winkelgeschwindigkeit omega, grosse Amplitude
figure(5)
plot(tNonlin2,phiNonlin2(:,2),  'linewidth',2, 'Color', 'k');
hold on;
plot(tLin2, phiLin2(:,2), '--', 'linewidth',2, 'Color', 'k');
hold off;

legend('nichtlinear', 'linearisiert');
xlabel('Zeit t');
ylabel('Winkelgeschwindigkeit \omega(t)')
axis([0 4*pi -3 3]);
set(gca,'YTick',-3*pi/4:pi/2:3*pi/4)
set(gca,'YTickLabel',{'-3pi/4','-pi/4','pi/4','3pi/4'})






