function S = assembleSteifigkeitsMatrix(A,p,nDirichlet)
% p:    Ruhelage der Knoten in der Ebene
% A:    Adjazenzmatrix (quadratisch, symmetrisch)
% nDirichlet: Anzahl Dirichletpunkte, am Ende von p

[n,n] = size(A);
m     = n - nDirichlet;
S     = zeros(2*m); 

% Schleife ueber alle Kanten (Balken) 
for i=1:m         % bewegliche Knoten
    for j=1:n     % alle Knoten
        if(A(i,j) > 0)   % Kante vorhanden
            xij = p(2*j-1:2*j) -  p(2*i-1:2*i);
            l   = norm(xij);
            e   = xij/l;
            SLokal = -e*e' / l;
            
            if(j <= m)
                S(2*i-1:2*i,2*j-1:2*j) ...
                    = S(2*i-1:2*i,2*j-1:2*j) + SLokal;
            end
            
            S(2*i-1:2*i,2*i-1:2*i) ...
                = S(2*i-1:2*i,2*i-1:2*i) -  SLokal;
        end     % if (A(i,j) > 0)
    end
end 
