%--------------------------------------------------------------------------   
%     Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%     Leslie-Modell mit drei Altersgruppen, Listing 6.1, 6.2:  
%     Author: Frank Hausser
%     Date:   4/2010
%--------------------------------------------------------------------------

clear all;
close all;

% Leslie - Matrix
L = [  0   3/2 1/2;
      1/2   0   0 ;
       0   1/2  0];
   
n = 20;             % Anzahl Zeitschritte 
N = length(L(1,:)); % Anzahl Altersgruppen

% (N,n+1)-Matrix p; k-te Spalte: Populationen zum Zeitpunkt k
p = zeros(N,n+1);   

% Startpopulation: gleichverteilt
p(:,1) = 100*ones(N,1);

% Zeit-Iteration
for k = 1:n
   p(:,k+1) = L*p(:,k);
end

%----------------- Visualisierung / Auswertung ----------------------------
t = [0:n];       % diskrete Zeitpunkte 

% Zeitentwicklung der Populationen
plot(t,p(1,:), t,p(2,:), t,p(3,:));
pause

% Relative Hufigkeiten der Altersgruppen 
pGesamt = sum(p);
plot(t,p(1,:)./pGesamt, t,p(2,:)./pGesamt, t,p(3,:)./pGesamt);
pause

% Asymptotisches Verhalten der Gesamtpopulation
[V,D] = eig(L);             % Eigenwerte /-vektoren berechnen
for i=1:N                   % normieren in der 1-Norm
    V(:,i) = V(:,i)/norm( V(:,i),1 ) 
end;
[domEW, ind] = max(diag(D))    % dominanter Eigenwert
domEV        = V(:,ind)        % dominanter Eigenvektor

alpha = V\p(:,1);              % Zerlegung der Anfangspopulation
                               % in Eigenvektoren
pAsymp    = zeros(n+1,1);
pAsymp(1) = alpha(ind);        % Koeffizient des dominanten EV
for k=1:n
    pAsymp(k+1) = pAsymp(k)*domEW;
end

% Halblogarithmischer Plot
semilogy(t,pGesamt,t,pAsymp);
axis([0,20,50,400]);
set(gca,'YTick',[50,100,200,400]);
