%--------------------------------------------------------------------------   
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%  
%   Lsung der Konvektions-Reaktions-Gleichung mit einer sinusfrmigen
%   Randbedingung fr die Parameter $v =0.1$, $\alpha = 0.1$.
%           Implementierung des expliziten Verfahrens
%           Code-Beispiel, Listing 6.11
%     Author: Yury Luchko
%     Date:   2/2010
%
%--------------------------------------------------------------------------

clear;
% System- und Verfahrensparameter
L = 1.0;  T = 20.; K = 200; n = 50;
dt = T/K;  dx = L/n;
v =.1; alpha = .1;  
d = v*dt/dx; c  = 1 - v*dt/dx - dt*alpha; 
% Speicherallozierung und Gitterpunkte
x = linspace(0,L,n+1);
time = linspace(0,T,K+1);
u = zeros(n+1, K+1);
% Anfangsbedingung
u(1:n/2,1) = sin(pi*x(1:n/2)*2);
% Randbedingung 
u(1,:) = abs(sin(pi*time(:)/8));
% Iterationsmatrix A und rechte Seite b_k
A = gallery('tridiag',n,d,c,0);
b  = zeros(n,1); 
% Berechnungen der Zeitentwicklung nach der Iterationsformel
for k = 1:K
    b(1) = d*u(1, k); 
    z = A*u(2:n+1, k) + b;
    u(2:n+1, k+1) = z';
end
% Visualisierung der Ergebnisse
mesh(x(1:2:end),time(1:8:end),u(1:2:end,1:8:end)')
xlabel('x');
ylabel('t');
zlabel('u(x,t)');