%--------------------------------------------------------------------------   
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%  
%   Lsung der Konvektions-Reaktions-Gleichung mit einer sinusfrmigen
%   Randbedingung fr die Parameter $v =0.1$, $\alpha = 0.1$
%           Implementierung des impliziten Verfahrens
%           Code-Beispiel, Listing 6.12
%     Author: Yury Luchko
%     Date:   2/2010
%
%--------------------------------------------------------------------------

clear;
% System- und Verfahrensparameter
L = 1.0;  T = 20.; K = 100; n = 100;
dt = T/K;  dx = L/n;
v =.1; alpha = .1;  
% Speicherallozierung und Gitterpunkte
x = linspace(0,L,n+1);
time = linspace(0,T,K+1);
u = zeros(n+1, K+1);
% Anfangsbedingung
u(1:n/2,1) = sin(pi*x(1:n/2)*2);
% Randbedingung 
u(1,:) = abs(sin(pi*time(:)/8));
% Konstruktion der Koeffizientenmatrix B
e = - v*dt/dx; f  = 1 + v*dt/dx + dt*alpha; 
B = gallery('tridiag',n,e,f,0);
% Konstruktion der rechten Seite c_k
% und Lsung des Systems fr alle Zeitschritte
for k = 1:K
    c(1) = -e*u(1, k+1) + u(2, k); 
    c(2:n) = u(3:n+1, k); 
    z = B\c';
    u(2:n+1, k+1) = z';
end
% Visualisierung der Ergebnisse
mesh(x,time,u')
xlabel('x');
ylabel('t');
zlabel('u(x,t)');

