%--------------------------------------------------------------------------   
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%  
%   Lsung der 3D-Transportglichung (6.20) nach dem
%   expliziten FD-Verfahren.  
%   Die Ergebnisse der Berechnungen werden 
%   mit dem Befehl slice visualisiert.
%
%     Authoren: Yury Luchko, Peter Otto und Witalij Wambold
%     Date:   1/2010
%
%--------------------------------------------------------------------------

clear;
% System- und Modellparameter werden gesetzt
L = 1.0; B = 1.0; H = 0.5; Tend = 2;
dt = 0.01; maxk = Tend/dt;
dx = 0.1; dy = 0.1; dz = 0.05;
nx = L/dx; ny = B/dy; nz = H/dz;
% Diffusionskoeffizient
disp = 0.05; 
%  Geschwindigkeit der Strmung
vel = 8*[ 0.1 0.005 0.1];   
% Abbaurate
dec = .01;     
% Speicherallokation fr die unbekannten Konzentrationen
x = dx*(0:nx); y = dy*(0:ny); z = dz*(0:nz);
u = zeros(nx+1,ny+1,nz+1,maxk+1);
% Anfangsbedingung
u(1:nx+1,1:ny+1,1:nz+1,1) = 1.; 
% Randbedingung
for k=1:maxk+1  
   for l=1:nz+1
        for i=1:nx+1
            u(i,1,l,k) =10.*(k<maxk/10);
        end
    end
end
% Eintrge fr die Iterationsmatrix wirden berechnet
rdx2 = 1./(dx^2); rdy2 = 1./(dy^2); rdz2 = 1./(dz^2);
central_value = 1 - dt*disp*2*(rdx2+rdy2+rdz2) - vel(1)*dt/dx - vel(2)*dt/dy - vel(3)*dt/dz - dt*dec;
x_negative = dt*(disp*rdx2 + vel(1)/dx); 
x_positive = dt*disp*rdx2; 
y_negative = dt*(disp*rdy2 + vel(2)/dy); 
y_positive = dt*disp*rdy2; 
z_negative = dt*(disp*rdz2 + vel(3)/dz);
z_positive = dt*disp*rdz2;
% Iterationsmatrix A wird angelegt
A = sparseMatrixFD3D( nx-1, ny-1, nz-1, central_value, x_negative, x_positive, y_negative, y_positive, z_negative, z_positive );
% Vektor b_k wird angelegt
for k=1:maxk   
    boundary = zeros(nx-1,ny-1,nz-1);
    boundary(1:nx-1, 1:ny-1, 1)     = z_negative*u(2:nx, 2:ny, 1, k); 
    boundary(1:nx-1, 1:ny-1, nz-1)	= z_positive*u(2:nx, 2:ny, nz+1, k); 
    boundary(1,    1:ny-1, 1:nz-1)  = boundary(1,    1:ny-1, 1:nz-1) + x_negative*u(1,    2:ny, 2:nz, k); 
    boundary(nx-1, 1:ny-1, 1:nz-1)  = boundary(nx-1, 1:ny-1, 1:nz-1) + x_positive*u(nx+1, 2:ny, 2:nz, k); 
    boundary(1:nx-1, 1,    1:nz-1)  = boundary(1:nx-1, 1,    1:nz-1) + y_negative*u(2:nx, 1,    2:nz, k); 
    boundary(1:nx-1, ny-1, 1:nz-1)  = boundary(1:nx-1, ny-1, 1:nz-1) + y_positive*u(2:nx, ny+1, 2:nz, k); 
    uk = u(2:nx,2:ny,2:nz,k);
    % Lsung im nchsten Zeitschritt wird 
    % nach der Iterationsformel A*u_k + b_k berechnet
    solution = A*uk(:) + boundary(:);
    % Lsung wird gespeichert
    u(2:nx,2:ny,2:nz,k+1) = reshape(solution,nx-1,ny-1,nz-1);
    % Lsung wird visualisiert
    v=u(:,:,:,k);
    xslice = 3*L/4; yslice = 3*B/4; zslice = H/3;
    slice(x,y,z,v,xslice,yslice,zslice)
    xlabel('x');
    ylabel('y');
    zlabel('z');
    colorbar
    colormap Cool
    pause
end

   
    