%--------------------------------------------------------------------------   
%     Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%     Van der Pol Oszillator, Listing 6.4: 
%        numerische Loesung fuer unterschiedliche Daempfungen
%        benoetigt die Funktion vanDerPolRHS, die rechte Seite der DGL
%     Author: Frank Hausser
%     Date:   4/2010
%--------------------------------------------------------------------------

close all;
clear all;

%--------------------------------------------------------------------------
global mu;   % globale Variable, Parameter im Van der Pol Oszillator

options = odeset('AbsTol',1.e-8,'RelTol',1.e-4,'Refine',20);
y0      = [0.5;0];     % Anfangswerte

%------------------ Test 1: linearer Oszillator ---------------------------
mu         = 0;
T          = 20*pi;
tIntervall = [0, T];
[t,y] = ode45(@vanDerPolRHS,tIntervall,y0,options);

% Plot der Loesung x(t) 
figure(1),
plot( t,y(:,1),'k', 'linewidth', 2 );
xlabel('t'); ylabel('x');
title('\mu = 0');
axis([0, T, -0.6, 0.6]);
pbaspect([3,1,1]);

% Plot der Phasenraum-Trajektorie (x(t), v(t)) (font size 10)
figure(2)
plot(y(:,1), y(:,2), 'k', 'linewidth',2);
xlabel('x(t)'); ylabel('v(t)');
title('\mu = 0');
axis([-0.6, 0.6, -0.6, 0.6]);
set(gca,'YTick',-0.5:0.5:0.5)
pbaspect([1,1,1]);
pause 

%------------- Test 2: schwach gedaempfter Oszillator ---------------------
mu         = 0.1;
T          = 20*pi;
tIntervall = [0, T];
[t,y] = ode45(@vanDerPolRHS,tIntervall,y0,options);
figure(1),
plot( t,y(:,1), 'k', 'linewidth', 2 );
xlabel('t'); ylabel('x');
title('\mu = 0.1');
axis([0, T, -2.1,2.1]);
pbaspect([3,1,1]);


figure(2)
plot(y(:,1), y(:,2), 'k', 'linewidth',2);
xlabel('x(t)'); ylabel('v(t)');
title('\mu = 0.1');
axis([-2.1, 2.1, -2.1, 2.1]);
pbaspect([1,1,1]);
pause 

%---------------  Test 3:  gedaempfter Oszillator -------------------------
mu         = 1;
T          = 20*pi;
tIntervall = [0, T];
[t,y] = ode45(@vanDerPolRHS,tIntervall,y0,options);
figure(1),
plot( t,y(:,1), 'k', 'linewidth', 2 );
xlabel('t'); ylabel('x');
title('\mu = 1');
axis([0, T, -2.1,2.1]);
pbaspect([3,1,1]);

figure(2)
plot(y(:,1), y(:,2), 'k', 'linewidth',2);
xlabel('x(t)'); ylabel('v(t)');
title('\mu = 1');
axis([-2.1, 2.1, -3.1, 3.1]);
pbaspect([1,1,1]);
pause 

%--------------  Test 4: stark gedaempfter Oszillator ---------------------
mu         = 10;
T          = 20*pi;
tIntervall = [0, T];
tic
[t,y] = ode45(@vanDerPolRHS,tIntervall,y0,options);
toc
figure(1),
plot( t,y(:,1), 'k', 'linewidth', 2 );
xlabel('t'); ylabel('x');
title('\mu = 10');
axis([0, T, -2.1, 2.1]);
pbaspect([3,1,1]);

figure(2)
plot(y(:,1), y(:,2), 'k', 'linewidth',2);
xlabel('x(t)'); ylabel('v(t)');
title('\mu = 10');
axis([-2.1, 2.1, -15, 15]);
pbaspect([1,1,1]);
