%--------------------------------------------------------------------------   
%   Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%   Fallstudie Google's PageRank (Listing 7.1):  
%
%   function [p] = pageRank(H, alpha, maxiter)
%        Berechnet den PageRank-Vektor p eines durch die Hyperlinkmatrix H
%        spezifizierten Internets mit der Vektoriteration
%     Eingabeparameter:
%        H       :   Hyperlinkmatrix  (als sparse-Matrix)
%        alpha   :   Parameter zum Aufbau der Google-Matrix, 0 < alpha < 1
%        maxiter :   Anzahl der Iteration bei der Vektoriteration
%     Rckgabeparameter:
%        p       :   PageRank-Vektor
%
%     Author: Witalij Wambold
%     Date:   3/2010
%--------------------------------------------------------------------------

function [p] = pageRank(H, alpha, maxiter)

[n, n] = size(H);
e      = ones(n,1);

% Bestimmung der Indizes der Nullzeilen (haengende Knoten)
zeilenSummenH = H*e;
zeilenIndizes = find(zeilenSummenH==0);

% Aufbau des Spaltenvektors a als sparse-Matrix 
l = length(zeilenIndizes);
spaltenIndizes = ones(l,1);
a = sparse(zeilenIndizes, spaltenIndizes, ones(l,1), n, 1);

% Anfangsverteilung pi0
p = (1/n) * e;

% Transponieren
HT = H'; aT = a';

% Vektoriteration
for i=1:maxiter
    p = alpha*HT*p + 1/n*e * ( alpha*(aT*p) + 1 - alpha );
end