%--------------------------------------------------------------------------
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%  Kapitel 8, Abbildung 8.1:
%       Exponentielles Wachstum und exponentielles Absterben. 
%       Berechnet und abgebildet werden die Lsungen (8.3) der
%       Differentialgleichung (8.1) 
%       mit der Anfangspopulation $N_0 = 1000$ 
%       und $\alpha = 1/5$  bzw. $\alpha = -1/5$. 
%
%
%     Author: Yury Luchko
%     Date:   3/2010
%--------------------------------------------------------------------------
clear all;
% Numerische Loesung der Maltusschen DGL
% 1. Fall: Vermehrungsrate ist groesser als die Sterberate 
% (exponentielles Wachstum) 
alpha = 0.2;
% Zeitintervall
T=15.0;
% Anfangsbedingung 
N0 = 1000;
% Rechte Seite der DGL
func=@(t,N) (alpha*N(1));
% Numerische Loesung der DGL mit dem Solver ode45
[t,N] = ode45(func,[0 T],N0);
% Visualisierung der Ergebnisse auf dem Zeitintervall [0,T]
subplot(1,2,1)
plot(t,N(:),'k','linewidth',2)
axis([0,T,0,2*10^4])
ylabel('N(t)')
xlabel('t')
% 2. Fall: Vermehrungsrate ist kleiner als die Sterberate
% (exponentielles Absterben)
alpha = -0.2;
% Rechte Seite der DGL
func=@(t,N) (alpha*N(1));
% Numerische Loesung der DGK mit dem Solver ode45
[t,N] = ode45(func,[0 T],N0);
% Visualisierung der Ergebnisse auf dem Zeitintervall [0,T]
subplot(1,2,2)
plot(t,N(:),'k','linewidth',2)
ylabel('N(t)')
xlabel('t')
