%--------------------------------------------------------------------------   
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%  
%   1D-Schadstoffausbreitung mit dominantem Abbau  fr v=0.5,
%   alpha = 0.5, L=5.0, T=10.0, v/(L*alpha)=0.2 << 1.
%           Abbildung 9.3 (rechts)
%     Author: Yury Luchko
%     Date:   1/2010
%
%--------------------------------------------------------------------------

clear;
% System- und Verfahrensparameter
L = 5.0;  T = 10.; K = 40; n = 40;
dt = T/K;  dx = L/n;
v =.5; alpha = .5;    
% Speicherallozierung und Gitterpunkte
x = linspace(0,L,n+1);
time = linspace(0,T,K+1);
u = zeros(n+1, K+1);
% Anfangsbedingung
u(:,1) = 1.0;
% Randbedingung 
u(1,:) = (sin(pi*time(:)/6))+1.0; 
% Konstruktion der Koeffizientenmatrix B
e = - v*dt/dx; f  = 1 + v*dt/dx + dt*alpha; 
B = gallery('tridiag',n,e,f,0);
% Konstruktion der rechten Seite c_k
% und Lsung des Systems fr alle Zeitschritte
for k = 1:K
    c(1) = -e*u(1, k+1) + u(2, k); 
    c(2:n) = u(3:n+1, k); 
    z = B\c';
    u(2:n+1, k+1) = z';
end
% Visualisierung der Ergebnisse
mesh(x,time,u')
xlabel('x');
ylabel('t');
zlabel('u(x,t)');

